//Edge RSS jQuery Code
//written by: Charles Easter
//version: Alpha v2

$(document).ready(function(){

//HTML VARIABLES
////================
var landingHTML = '',
	appHTML = '',
	settingsHTML = '',
	loginErrorHTML = '',
	body = $('body')
;

//Gets the HTML from the skeleton
$.ajax({
	url: 'xhr/skeleton.html',
	type: 'get',
	dataType: 'html',
	cache: false,
	success: function(h){
		landingHTML = $(h).find('#landing-html');
		appHTML = $(h).find('#app-html');
		loginErrorHTML = $(h).find('#login-error');
		settingsHTML = $(h).find('#settings-html');
		settingsHTML.dialog({
			autoOpen: false,
			modal: true,
			title: 'Settings',
			width: 450
		});
		init();			
	}
});
//FUNCTIONS
////================
	//initializes the application
	var init = function(){
		checkLogin();
	};
		//checks to see if user is logged in
	var checkLogin = function(){
		$.ajax({
				url: 'xhr/protect.php',
				type: 'get',
				dataType: 'json',
				cache: false,
				success: function(r){
					r.error ? loadLand() : loadApp();
				}
			});
	};
	//Loads the Home Page
	//===================
	var loadLand = function(){
		
		$('#app-html').length ? $('#app-html').remove() : null;
		loginErrorHTML.length ? loginErrorHTML.remove() : null;
		
		landingHTML
			.prependTo(body)
			.hide()
			.fadeIn(500)
		;
		
	
		/* (landingHTML).hide().fadeIn(500); */
		
		var emailInput = $('input.text_input:eq(0)'),
			passphraseInput = $('input.text_input:eq(1)')
		;
		
		emailInput.val('enter email');
		passphraseInput.val('enter password');
		
		//focus & blur events
		emailInput.focus(function(e){
			emailInput.val('');
		});
		emailInput.blur(function(e){
			emailInput.val() === '' ? emailInput.val('enter email') : null;
		});
		passphraseInput.focus(function(){
			passphraseInput.val('');
		});
		passphraseInput.blur(function(){
			passphraseInput.val() === '' ? passphraseInput.val('enter password') : null;
		});
	};
	
	//Loads the Main Application
	//==============================
	var loadApp = function(){
		
		$('#landing-html').length ? $('#landing-html').remove() : null;
		
		appHTML
			.prependTo(body)
			.hide()
			.fadeIn(500)
		;
		
		buildNav();
	};
	
	//Builds the Navigation Menu
	//==========================
	var buildNav = function(){
		
		var nav = $('#navigation'),
			navList = nav.find('ul')
		;
		
		navList.empty();
		
		//Ajax call to retrieve the list of active and inactive RSS Feeds
		$.ajax({
				url: 'xhr/get_all.php',
				type: 'get',
				dataType: 'json',
				cache: false,
				success: function(r){
					console.log(r);
					for(var i = 0, j = r.actives.length; i < j; i++ ){
						
						//reference to active rss feeds
						var currentFeed = r.actives[i];

						$('<li><a href="' + currentFeed.url + '" rel=" ' + currentFeed.id + '">' + currentFeed.title + '</a></li>').appendTo(navList);
					
					};
					//Makes the first anchor active
					navList.find('a:first').addClass('current');
					
					//Loads Initial Feed's Articles				
					loadArticles(5);
				}
			});
	};
	//Loads The Articles
	//==================
	//Accepts a number argument for how many articles to pull from the feed
	var loadArticles = function(numArticles){
		
		//Are there articles already Loaded? If so remove them
		$('#non_nav_wrap .article').remove();
		
		//If an argument is not passed in, load 4 articles
		numArticles === undefined ? numArticles = 4 : numArticles = numArticles;
		
		//sets the value of URL equal the the active navigation item's URL attribute and instantiates the Google Feed
		var url = $('.current').attr('href'),
			feed = new google.feeds.Feed(url)
		;
				
		//Setup the Feed Options
		feed.includeHistoricalEntries();
		feed.setNumEntries(numArticles);
		
		//Google Syndication Feeds Load
		feed.load(function(result){
			
			//Builds each article from the article template script tag
			$('#articleTemplate')
				.tmpl(result.feed.entries)
				.appendTo('#non_nav_wrap')
				.hide()
				.fadeIn(1000)
			;
			
			//Sets up reference to all the articles
			var articles = $('.article');
			
			//Loops over each article and sets their date dynamically
			articles.each(function(i){
				
				var date = Date.parse(result.feed.entries[i].publishedDate),
					day = date.toString('d'),
					month = date.toString('MMMM'),
					article = $(this)
				;
				
				article.find('.article_date_number').text(day);
				$('.article_date_month:eq(' + i + ')').text(month);
				
				//Sets the author to unknown if none is provided in the article entry from google
				$('.article_author strong:eq(' + i + ')').text() === '' ? $('.article_author strong:eq(' + i + ')').text('Unknown') : null;
			});	
		});
	};
	
	var buildSettings = function(){
		$.ajax({
				url: 'xhr/get_all.php',
				type: 'get',
				dataType: 'json',
				success: function(r){
					$('#active_feeds li').remove();
					$('#inactive_feeds li').remove();
					console.log(r);
					var activeFeeds = r.actives,
						inactiveFeeds = r.inactives
					;
					for(var i=0, j=activeFeeds.length; i<j; i++){
						$('<li class="settings_li" rel="' + activeFeeds[i].id + '">' + activeFeeds[i].title + '</li>').appendTo('#active_feeds');
					}
					for(var k=0, l=inactiveFeeds.length; k<l; k++){
						$('<li class="settings_li" rel="' + inactiveFeeds[k].id + '">' + inactiveFeeds[k].title + '</li>').appendTo('#inactive_feeds');
					}
					
					$('#active_feeds, #inactive_feeds')
						.addClass('connectedSortable')
						.sortable({
							connectWith: '.connectedSortable',
							items: 'li'
						})
					;
				}
			});
	};
//EVENTS
//================

	$('#active_feeds').live('sortreceive', function(e, ui){		
		var item = $(ui.item);
		
		$.ajax({
					url: 'xhr/modify.php',
					type: 'get',
					dataType: 'json',
					data: {id: item.attr('rel'), addrem: 'actives'},
					success: function(r){
						//callback code
						buildNav();
					}
				});

	});
	$('#inactive_feeds').live('sortreceive', function(e, ui){
		var item = $(ui.item);
		
		$.ajax({
					url: 'xhr/modify.php',
					type: 'get',
					dataType: 'json',
					data: {id: item.attr('rel'), addrem: 'inactives'},
					success: function(r){
						//callback code
						buildNav();
					}
				});
		

	});
	$('#settings_btn').live('click', function(e){
		buildSettings();
		settingsHTML.dialog('open');
		
		
			
		
		e.preventDefault();
	});
	//Navigation anchors
	$('#navigation ul li a').live('click',function(e){

    	$('#navigation ul li a').hasClass('current') ? $('#navigation ul li a').removeClass('current') : null;
    	
    	$(this).addClass('current');
    	
    	loadArticles(5);
    	
   		 e.preventDefault();
	});
	
	
	//Logout Button
	$('#settings_logout').live('click', function(e){
		$.ajax({
			url: 'xhr/logout.php',
			type: 'get',
			dataType: 'json',
			success: function(r){
				r.success ? checkLogin() : alert('logout did not work for some reason');
				
			}
		});
		e.preventDefault();
	});
	//Sign In Button
	$('#sign_in').live('click', function(e){
			
			$('#login').css({position: 'relative'});
			
			var createError = function(){
				loginErrorHTML
					.css({
						position: 'absolute',
						top: -30,
						left: 0
					})
					.prependTo('#login')
				;
			};
			
			var emailInput = $('input.text_input:eq(0)'),
				passphraseInput = $('input.text_input:eq(1)'),
				credentials = {
					login: emailInput.val(),
					passphrase: passphraseInput.val()
				}
			;
			//Login Ajax call
			$.ajax({
					url: 'xhr/login.php',
					type: 'get',
					data: credentials,
					dataType: 'json',
					success: function(r){
						//callback code
						r.user ? loadApp() : createError() ;
					}
				});
			e.preventDefault();
		});
	$('#add_feed_btn').live('click', function(e){
		buildSettings();
		
		/* e.preventDefault(); */
	});
});